@@ -65,30 +65,14 @@
 /* definition de tous les type de bus */
 Tsearchdrive listesearchdrives[] = {
     { "", "", " ", 100 }, /* scsi (sg) */
-    { "dev=ATA:", "ATA:", "ATA", 80 }, /* ide sg */
-    { "dev=ATAPI:", "ATAPI:", "ATAPI", 60 }, /* ide */
 #ifdef LINUX_IDE  /* pure ide devices with linux */
     { "dev=/dev/hda", "/dev/hda", "IDE", 40 },
     { "dev=/dev/hdb", "/dev/hdb", "IDE", 40 },
     { "dev=/dev/hdc", "/dev/hdc", "IDE", 40},
     { "dev=/dev/hdd", "/dev/hdd", "IDE", 40 },
-    { "dev=/dev/hde", "/dev/hde", "IDE", 40 },
-    { "dev=/dev/hdf", "/dev/hdf", "IDE", 40 },
-    { "dev=/dev/hdg", "/dev/hdg", "IDE", 40 },
-    { "dev=/dev/hdh", "/dev/hdh", "IDE", 40 },
-    { "dev=/dev/hdi", "/dev/hdi", "IDE", 40 },
-    { "dev=/dev/hdj", "/dev/hdj", "IDE", 40 },
-    { "dev=/dev/hdk", "/dev/hdk", "IDE", 40 },
-    { "dev=/dev/hdl", "/dev/hdl", "IDE", 40 },
-    { "dev=/dev/hdm", "/dev/hdm", "IDE", 40 },
-    { "dev=/dev/hdn", "/dev/hdn", "IDE", 40 },
-    { "dev=/dev/hdo", "/dev/hdo", "IDE", 40 },
-    { "dev=/dev/hdp", "/dev/hdp", "IDE", 40 },
-    { "dev=/dev/hdq", "/dev/hdq", "IDE", 40 },
-    { "dev=/dev/hdr", "/dev/hdr", "IDE", 40 },
-    { "dev=/dev/hds", "/dev/hds", "IDE", 40 },
-    { "dev=/dev/hdt", "/dev/hdt", "IDE", 40 },
 #endif
+    { "dev=ATA:", "ATA:", "ATA", 80 }, /* ide sg */
+    { "dev=ATAPI:", "ATAPI:", "ATAPI", 60 }, /* ide */
     { NULL, NULL, NULL, 0}
   };
 
@@ -311,6 +295,15 @@ gchar *burn_data_getextrapara(GHashTable *Ahash)
   return Lreturn;
 }
 
+gchar *get_blank_type(GHashTable *Ahash)
+{
+  gboolean *Luseautoblank = (gboolean *) g_hash_table_lookup(Ahash, "useautoblank");
+
+  if (!*Luseautoblank) return g_strdup("");
+
+  return g_strdup_printf("blank=%s", conf_get_boolean("fastblank") == TRUE ? "fast" : "all");
+}
+
 /* copie d'une image iso */
 gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
   gchar **Lcmd;
@@ -318,6 +311,7 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
   GIOChannel *Lcom, *Lcomerr;
   guint Lcomevent, Lcomerrevent;
   gint *Lcont = (gint *) g_hash_table_lookup(Ahash, "cont");
+  gboolean *Labort = (gboolean *) g_hash_table_lookup(Ahash, "gabort");
   GtkWindow *Lwindow = GTK_WINDOW(g_hash_table_lookup(Ahash, "window_burn"));
   gboolean Lsimul = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(sc_hash_table_lookupv(Ahash, "%ssimul", Aop)));
   gint Lnbrgravure = gtk_spin_button_get_value(GTK_SPIN_BUTTON(sc_hash_table_lookupv(Ahash, "nbrcd%s", Aop)));  
@@ -336,13 +330,15 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
   gint *Ldone = (gint *)g_hash_table_lookup(Ahash, "done"); /* fais */
   gint Lcurcd;
   gint Lnbrpass=1;
-  gchar *Lbufvitesse;
+  gchar *Lbufvitesse, *Lblank;
   gchar Llasttrack[_BUF_SIZE] = "00";
   gint g_out, g_err, Lnbrarg;
   gboolean Lstatus = FALSE;
   gboolean Leject = FALSE;
   GtkToggleButton *Ltbtn = NULL;
 
+  Lblank = get_blank_type(Ahash);
+
   if ((Ltbtn = GTK_TOGGLE_BUTTON(sc_hash_table_lookupv(Ahash, "%smulti", Aop))))
     Lmulti =gtk_toggle_button_get_active(Ltbtn);
 
@@ -351,6 +347,7 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
   for (Lcurcd=1; Lcurcd<= Lnbrgravure;
       ((Lsimul && Lnbrpass>1) || (!Lsimul)) ? ( Lcurcd++, Lnbrpass=1 ) : ( Lnbrpass++ )) {
 
+    Ldosimul = (Lsimul && Lnbrpass==1);
     if (Lcurcd > 1 && !Ldosimul) {
       /* copie sur un nouveau cd, on demande a l'utilisateur d'inserer le
        * nouveau cd vierge */
@@ -362,14 +359,12 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
       Lrep = gtk_dialog_run(GTK_DIALOG(Lconfirm));
       gtk_widget_destroy(Lconfirm);
       if (Lrep == GTK_RESPONSE_NO) {
-        gboolean *Labort = (gboolean *) g_hash_table_lookup(Ahash, "gabort");
         /* si c'est non alors on arrete */
         *Labort = TRUE;
-        return TRUE;
+        Lstatus = TRUE;
       }
 
     }
-    Ldosimul = (Lsimul && Lnbrpass==1);
 
     /* faut il ejecter le CD-R apres l'operation ?
      * oui si l'utilisateur a cocher la case "ejecter le cd" ou
@@ -385,13 +380,14 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
 
     Lbufvitesse = get_combo_value(Lvitesse);
     Lbufgrav = get_combo_value(Lgraveur);
-    Lcommandline = g_strdup_printf("%s dev=%s -v gracetime=2 %s%s %s %s %s %s %s %s '%s'",
+    Lcommandline = g_strdup_printf("%s dev=%s -v gracetime=2 %s%s %s %s %s %s %s %s %s '%s'",
         conf_get_string("cdrecord"), Lbufgrav, *Lbufvitesse != '0' ? "speed=" : "", 
         *Lbufvitesse != '0' ? Lbufvitesse : "",  
         Ldosimul ? " -dummy" : "",  /* simulation ? */
         Ldosimul || Lnotfix ? " -nofix" : "", /* fixer le cd apres ecriture ? */
         Lmulti ? " -multi" : "",  /* multi-session */
         Leject ? "-eject" : "", /* ejecter le cd apres l'operation */
+        Lblank,
         Lextrapara && *Lextrapara ? *Lextrapara : "",  /* parametre supplementaire tel que le mode d'ecriture */
         conf_get_string("cdrecordpara"),
         *Liso);
@@ -403,7 +399,7 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
     Lstatus = g_shell_parse_argv(Lcommandline, &Lnbrarg, &Lcmd, Aerror);
     g_free(Lcommandline);
     if (Lstatus == FALSE) {
-      return FALSE;
+      break;
     }
 
     Lstatus = g_spawn_async_with_pipes(NULL, Lcmd, NULL, /* env argument */
@@ -413,7 +409,7 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
 
     if (Lstatus == FALSE) {
       g_warning("ERROR EXECUTION !\n");
-      return FALSE;
+      break;
     }
 
     *Lcont = 1;
@@ -432,7 +428,7 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
     Lcomerrevent = g_io_add_watch (Lcomerr, (G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_PRI),
                                       cdrecord_grave_callback, Ahash); 
     
-    while (*Lcont > 0) {
+    while (*Lcont > 0 && *Labort == FALSE) {
       gtk_main_iteration();    
     }
     g_source_remove(Lcomevent);
@@ -449,7 +445,8 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
 
     if (*Aerror) {
       _DEB("IL Y A UNE ERREUR !!");
-      return FALSE;
+      Lstatus = FALSE;
+      break; 
     }
 
     if (*Loperationstatus == FALSE) {
@@ -457,7 +454,8 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
        * dans tous les cas ce n'est pas normal, on genere une erreur */
       g_set_error(Aerror, GRAVEMAN_ERROR, _ERR_UNKNOWN_ERROR, 
         _("Communication error with cdrecord. Check that you have access to cdrecord release 2.0 !"));
-      return FALSE;
+      Lstatus = FALSE;
+      break;
     }
 
     if (Ldosimul) {
@@ -471,10 +469,10 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
       Lrep = gtk_dialog_run(GTK_DIALOG(Lconfirm));
       gtk_widget_destroy(Lconfirm);
       if (Lrep == GTK_RESPONSE_NO) {
-        gboolean *Labort = (gboolean *) g_hash_table_lookup(Ahash, "gabort");
         /* si c'est non alors on arrete */
         *Labort = TRUE;
-        return TRUE;
+        Lstatus = TRUE;
+        break;
       }
     }
 
@@ -482,6 +480,8 @@ gboolean burn_from_image(gchar *Aop, GHashTable *Ahash, GError **Aerror) {
     strcpy(Llasttrack, "00");
   }
 
+  g_free(Lblank);
+  
   return Lstatus;
 }
 
@@ -629,13 +629,14 @@ _DEB("===>%s", Lbuffer);
     gtk_label_set_text(Ltitle, _("Fixating..."));
   } else if ((f=strstr(Lbuffer, CDRECORD_STATUS))) {
     gboolean *Lstatus = (gboolean *) g_hash_table_lookup(Lhash, "operationstatus");
-
+/* bug 11803
+ * cause des problems apparements, a tester .. 
     f=f+strlen(CDRECORD_STATUS);
-    /* fin de la gravure */
+     fin de la gravure 
     if (*f != '0') {
       g_set_error(Lerreur, GRAVEMAN_ERROR, _ERR_BUF_EMPTY, _("Error writing tracks, buffer was empty !"));
       return FALSE;
-    }
+    } */
     /* ok tout s'est bien passe ! */
     *Lstatus = TRUE;
   } else if (strstr(Lbuffer, CDRECORD_INPUTOUTPUT_ERROR)) {
@@ -687,6 +688,7 @@ gboolean gravepiste(GHashTable *Ahash, GError **Aerror) {
   GtkWidget *Lgraveur = g_hash_table_lookup(Ahash, "dstaudiocombo");
   gchar **Lrepertoire = (gchar **)g_hash_table_lookup(Ahash, "tmpdir");
   gboolean *Loperationstatus = (gboolean *)g_hash_table_lookup(Ahash, "operationstatus");
+  gboolean *Labort = (gboolean *) g_hash_table_lookup(Ahash, "gabort");
   gchar *Lbuftitle = NULL;
   gchar **Lcmd;
   gchar *Lcommandline;
@@ -703,18 +705,20 @@ gboolean gravepiste(GHashTable *Ahash, GError **Aerror) {
   gchar *Lbufvitesse, *Lbufgrav;
   gboolean Lsimul = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(g_hash_table_lookup(Ahash, "audiosimul")));
   gboolean Lnotfix = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(g_hash_table_lookup(Ahash, "audionotfix")));
+  gboolean Ldaomode = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(g_hash_table_lookup(Ahash, "audiodao")));
   gint Lnbrgravure = gtk_spin_button_get_value(GTK_SPIN_BUTTON(g_hash_table_lookup(Ahash, "nbrcdaudio")));
   gboolean Lwanteject = conf_get_boolean("eject");
   gint Lcurcd;
   gboolean Ldosimul;
   gint Lnbrpass=1;
-  gchar *Lfileslist;
+  gchar *Lfileslist, *Lblank;
   gboolean Leject = FALSE;
   gchar Llasttrack[_BUF_SIZE] = "00";
 
   Lfileslist = make_audio_fileslist(*Ltodo);
   Lbufvitesse = get_combo_value(Lvitesse);
   Lbufgrav = get_combo_value(Lgraveur);
+  Lblank = get_blank_type(Ahash);
 
   *Ltodo = (*Ltodo) * ((Lnbrgravure) + (Lsimul ? 1 : 0));
 
@@ -722,8 +726,26 @@ gboolean gravepiste(GHashTable *Ahash, GError **Aerror) {
   for (Lcurcd=1; Lcurcd<= Lnbrgravure;
       ((Lsimul && Lnbrpass>1) || (!Lsimul)) ? ( Lcurcd++, Lnbrpass=1 ) : ( Lnbrpass++ )) { 
     *Loperationstatus = FALSE;
-
     Ldosimul = (Lsimul && Lnbrpass==1);
+
+    if (Lcurcd > 1 && !Ldosimul) {
+      /* copie sur un nouveau cd, on demande a l'utilisateur d'inserer le
+       * nouveau cd vierge */
+      gint Lrep;
+      GtkWidget *Lconfirm = gtk_message_dialog_new(Lwindow,
+                                              GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION,
+                                              GTK_BUTTONS_YES_NO,
+                 _("Now you should insert next CD-R, do you want to continue operation ?"));
+      Lrep = gtk_dialog_run(GTK_DIALOG(Lconfirm));
+      gtk_widget_destroy(Lconfirm);
+      if (Lrep == GTK_RESPONSE_NO) {
+        /* si c'est non alors on arrete */
+        *Labort = TRUE;
+        Lstatus = TRUE;
+      }
+
+    }
+
     Lbuftitle = get_title(Lnbrgravure, Lcurcd, Ldosimul);
     gtk_label_set_text(GTK_LABEL(Ltitle), Lbuftitle);
     g_free(Lbuftitle);
@@ -733,18 +755,20 @@ gboolean gravepiste(GHashTable *Ahash, GError **Aerror) {
      * si il faut realiser d'autre gravure sur d'autres CD-R */
     Leject = ((Lcurcd > 1 && (Lwanteject || Lcurcd<Lnbrgravure)) || (Lcurcd == 1 && !Ldosimul && Lwanteject));
 
-    Lcommandline = g_strdup_printf("%s dev=%s -v gracetime=2 %s%s %s%s %s %s -pad -audio %s", 
+    Lcommandline = g_strdup_printf("%s dev=%s -v gracetime=2 %s%s %s%s %s %s %s %s -pad -audio %s", 
         conf_get_string("cdrecord"), Lbufgrav, *Lbufvitesse == '0' ? "" : "speed=", *Lbufvitesse == '0' ? "" : Lbufvitesse,
         Ldosimul ? " -dummy" : "",  /* simulation ? */ 
         Ldosimul || Lnotfix ? " -nofix" : "", /* fixer le cd apres ecriture ? */
+        Ldaomode ? " -dao" : "",  /* ecriture en mode DAO, pas de pause entre les pistes */
         Leject ? "-eject" : "", /* ejecter le cd apres l'operation */
+        Lblank, /* effacer le cdrw avant ? */
         conf_get_string("cdrecordpara"),
         Lfileslist);
 _DEB("execution [%s]\n", Lcommandline);
     Lstatus = g_shell_parse_argv(Lcommandline, &Lnbrarg, &Lcmd, Aerror);
     g_free(Lcommandline);
     if (Lstatus == FALSE) {
-      return FALSE;
+      break;
     }
 
     Lstatus = g_spawn_async_with_pipes(*Lrepertoire, Lcmd, NULL, /* env argument */
@@ -754,7 +778,7 @@ _DEB("execution [%s]\n", Lcommandline);
 
     if (Lstatus == FALSE) {
       g_warning("ERROR EXECUTION !\n");
-      return FALSE;
+      break;
     }
 
     *Lcont = 1;
@@ -773,7 +797,7 @@ _DEB("execution [%s]\n", Lcommandline);
     Lcomerrevent = g_io_add_watch (Lcomerr, (G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_PRI),
                                         cdrecord_grave_callback, Ahash);  
     
-    while (*Lcont>0) {
+    while (*Lcont>0 && *Labort == FALSE) {
       gtk_main_iteration(); 
     }
 
@@ -813,7 +837,6 @@ _DEB("execution [%s]\n", Lcommandline);
       Lrep = gtk_dialog_run(GTK_DIALOG(Lconfirm));
       gtk_widget_destroy(Lconfirm);
       if (Lrep == GTK_RESPONSE_NO) {
-        gboolean *Labort = (gboolean *) g_hash_table_lookup(Ahash, "gabort");
         /* si c'est non alors on arrete */
         *Labort = TRUE;
         Lstatus = TRUE;
@@ -824,6 +847,7 @@ _DEB("execution [%s]\n", Lcommandline);
     strcpy(Llasttrack, "00");
   }
 
+  g_free(Lblank);
   g_free(Lbufgrav);
   g_free(Lbufvitesse);
   g_free(Lfileslist);
@@ -888,16 +912,18 @@ gboolean perform_erase_cdrw(GHashTable *Ahash, GError **Aerror)
   gint g_out, g_err, Lnbrarg;
   gint *Lcont = g_hash_table_lookup(Ahash, "cont");
   GtkWidget *Lgraveur = g_hash_table_lookup(Ahash, "dstothercombo");
+  gboolean *Lfastblank = g_hash_table_lookup(Ahash, "usefastblank");
 
   /* pid de cdrecord */
   gint *Lpid = (gint *) g_hash_table_lookup(Ahash, "pid");
 
   Lbufgrav = get_combo_value(Lgraveur);
   Lcommandline = g_strdup_printf("%s dev=%s -v gracetime=2 blank=%s",
-      conf_get_string("cdrecord"), Lbufgrav, conf_get_boolean("fastblank") ? "fast" : "all");
+      conf_get_string("cdrecord"), Lbufgrav, (*Lfastblank == TRUE ? "fast" : "all"));
   g_free(Lbufgrav);
 
   _DEB("execution [%s]\n", Lcommandline);
+  printf("execution [%s]\n", Lcommandline);
   Lstatus = g_shell_parse_argv(Lcommandline, &Lnbrarg, &Lcmd, Aerror);
   g_free(Lcommandline);
 
