@@ -94,6 +94,10 @@
 #define SEARCH_PROG     2
 #define WRITE_CONFIG    4
 #define UPDATE_SIZE     8
+#define UPDATE_SAVEONEXIT_VALUE 16
+
+#define MENU_NEW        0
+#define MENU_UPDATE     1
 
 /* gestion CD de boot */
 #define CDBOOT_NONE     0
@@ -129,10 +133,18 @@ typedef enum {
 typedef struct {
   Ttypeconf type;
   gchar *entry;
-  gboolean indispensable;
   gchar *defaultvalue;
+  guint level;
 } TProgRequis;
 
+/* operation a faire sur une entre de la configuration */
+#define CONF_SAVEALWAYS 0
+#define CONF_SAVEONEXIT 1
+#define CONF_COMBO      16
+#define CONF_SPIN       32
+#define CONF_CHECK      64
+
+/* type des devices */
 #define _OTHER_DEVICE 0
 #define _READ_CDR     1
 #define _WRITE_CDR    2
@@ -145,7 +157,7 @@ typedef struct {
 #define DRIVE_DVDREADER(drive) (drive && (drive->type & _READ_DVD))
 #define DRIVE_DVDWRITER(drive) (drive && (drive->type & _WRITE_DVD))
 
-#define DRIVE_CDRW_WRITER(drive) (drive && (drive->type & _WRITE_CDRW))
+ #define DRIVE_CDRW_WRITER(drive) (drive && (drive->type & _WRITE_CDRW))
 #define DRIVE_ICONE(drive)  (drive->type & _WRITE_DVD ? GDVDRWpetiteIcone : \
                             (drive->type & _WRITE_CDR ? GCDRWpetiteIcone : \
                             (drive->type & _READ_DVD ? GDVDpetiteIcone : GCDpetiteIcone)))
@@ -197,24 +209,32 @@ extern GdkPixbuf *GEraseCdrw;
 extern GdkPixbuf *GCDIcone;
 extern GdkPixbuf *GAudioIcone;
 extern GdkPixbuf *GCDRWIcone;
+extern GdkPixbuf *GMenuAudio;
+extern GdkPixbuf *GMenuData;
+extern GdkPixbuf *GMenuCopy;
+extern GdkPixbuf *GMenuOther;
 extern GdkPixbuf *GCDpetiteIcone;
 extern GdkPixbuf *GCDRWpetiteIcone;
 extern GdkPixbuf *GDVDpetiteIcone;
 extern GdkPixbuf *GDVDRWpetiteIcone;
 
+/* images.c */
 extern void load_all_images();
 extern void free_all_images();
+extern void load_menu_images(gchar *Lquel);
+extern void prepare_menu_images(GHashTable *Ahash);
 
 /* interface.c */
 extern GSList *Gmedialist;
 extern Tmediaentry Gdefaultmedia[];
-extern void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident);
+extern void remplirecombovitesse(GtkComboBox *Acombo, gchar *Alecident, gchar *Aselvalue);
 extern void show_graverwindow(GHashTable *Ahash, gchar *Aaction, gchar *Atitle);
 extern GtkWidget* create_addfileselection (GtkWindow *AParent);
 extern GtkWidget* create_adddirselection (GtkWindow *AParent);
 extern GtkMenu *create_gtkpopupmenudata(GtkWidget *Aliste, GHashTable *Ahash);
 extern GtkMenu *create_gtkpopupmenuaudio(GtkWidget *Aliste, GHashTable *Ahash);
 extern GtkMenu *create_gtkpopupmenudevices(GtkWidget *Aliste, GHashTable *Ahash);
+extern GtkMenu *create_gtkpopupmenudisplay(GtkWidget *Aliste, GHashTable *Ahash);
 extern gboolean gtk_do_eventbuttonpress(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
 extern GtkWidget* create_addpisteselection (GtkWindow *AParent);
 extern GladeXML *create_window_encours(GtkWidget *AParent);
@@ -239,6 +259,11 @@ extern void manage_combobox_devicebus(GtkComboBox *Acombobox, Tdriveinfo *Adrive
 extern GHashTable *create_dialog_edit_device(GtkWidget *Aparent, Tdriveinfo *Adrive);
 extern GHashTable *create_dialog_add_device(GtkWidget *Aparent);
 extern GHashTable *addmediaformat(GHashTable *Aparent);
+extern void manage_top_menu(GHashTable *Ahash, gint Aaction);
+extern void gtk_toggle_top_menu(GtkTreeView *Atopmenu, gpointer Adata);
+extern GHashTable *create_dialog_confirm_operation (GtkWidget *Aparent, gchar *Alabel, 
+                      gchar *Acheckboxlbl, gboolean Acheckboxstatus);
+extern void update_status_bar_display(GHashTable *Ahash);
 
 /* log.c */
 extern GQuark graveman_error_quark (void);
@@ -252,18 +277,19 @@ extern void config_init();
 extern void clean_config();
 extern gchar *get_config_file_name();
 extern gint is_config_valide();
-extern gint manage_new_config(GHashTable *Ahash, gshort Aop, GError **Aerror);
+extern gint manage_config(GHashTable *Ahash, gshort Aop, GError **Aerror);
 extern gint Gfifosize;
 extern gchar *conf_get_string(gchar *Anom);
 extern gchar *conf_get_string_def(gchar *Anom, gchar *Adefault);
 extern gint conf_get_int(gchar *Anom);
 extern gboolean conf_get_boolean(gchar *Anom);
+extern void restore_last_used_values(GHashTable *Ahash);
 extern void conf_store_value(gchar *Aentry, gchar *Avalue);
 extern void conf_store_int(gchar *Aentry, gint Avalue);
 extern gint write_conf(gchar *AFichier, GError **Aerror);
 extern void maj_proprietes_prog(GHashTable *Ahash);
-extern void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gboolean Adoinit);
-extern void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi);
+extern void remplirecombo (GtkComboBox *Acombo, gchar *Abasename, Tmyentry *Aentry, gboolean Adoinit, gchar *Aselvalue);
+extern void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi, gchar *Aselvalue);
 extern void remplirelistegraveur(GtkTreeView *Aliste);
 extern gboolean read_config(GError **Aerror);
 extern void restore_main_window_pos(GtkWidget *Awindow1);
@@ -283,6 +309,7 @@ extern gboolean burn_audio(GHashTable *Ahash, GError **Aerror);
 extern gboolean burn_copy(GHashTable *Ahash, GError **Aerror);
 extern gboolean deltempdir(gchar *Ldirpath);
 extern void put_devicelabel(Tdriveinfo *Adrive, gchar *Abuf, gint Asizemax);
+extern Tdriveinfo *get_drive_cmb(GtkComboBox *Acombo);
 
 /* cdrecord.c */
 extern gchar *burn_data_getextrapara(GHashTable *Ahash);
@@ -349,9 +376,6 @@ extern void gtk_devices_add(GtkWidget *Abtn, gpointer Adata);
 extern gboolean encours_callback(gpointer Adata);
 extern void on_about (GtkMenuItem *Amenuitem, gpointer Adata);
 extern gboolean on_closeabout (GtkWidget *Awidget, GdkEventButton *Aevent, gpointer Adata);
-extern void on_togglecopiecd_clicked (GtkButton *Abutton, gpointer Adata);
-extern void on_togglecdaudio_clicked (GtkButton *Abutton, gpointer Adata);
-extern void on_togglecddata_clicked (GtkButton *Abutton, gpointer Adata);
 extern void on_selectgraveur(GtkWidget *Acombo, gpointer Adata);
 extern void gtk_file_sel(GtkWidget *Abtn, gpointer Adata);
 extern void confirm_erasecdrw (GtkWidget *Abtn, gpointer Adata);
@@ -368,7 +392,6 @@ extern void gtk_data_creerrepertoire(GtkWidget *btn, gpointer Adata);
 extern void gtk_audio_addtrack(GtkWidget *btn, gpointer Adata);
 extern void gtk_data_expandelement(GtkWidget *btn, gpointer Adata);
 extern void gonextpage(GtkWidget *Abtn, GtkNotebook *Anotebook);
-extern void changemenu(GtkToggleButton *Abutton, gpointer Adata);
 extern void text_buffer_callback(GtkTextBuffer *Aobj, gpointer Adata);
 extern void menu_active_panel(GtkWidget *Amenuitem, gpointer Adata);
 extern void gtk_combotext_changed(GtkWidget *Acombo, gpointer Adata);
@@ -379,12 +402,15 @@ extern void chercheprog(GtkWidget *Aobj, gpointer data);
 extern void abort_encours(GtkWidget *Abtn, gpointer Adata);
 extern void menu_quit(GtkWidget *Aobj1, gpointer Adata);
 extern void delete_event_quit(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
+extern void delete_event_encours(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
 extern void view_popupmenu_addaudio(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
 extern void key_popupmenu_addaudio(GtkWidget *Aliste, gpointer Adata);
 extern void view_popupmenu_addfile(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
 extern void key_popupmenu_addfile(GtkWidget *Aliste, gpointer Adata);
 extern void view_popupmenu_devices(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
 extern void key_popupmenu_devices(GtkWidget *Aliste, gpointer Adata);
+extern void view_popupmenu_display(GtkWidget *Aliste, GdkEventButton *Aevent, gpointer Adata);
+extern void key_popupmenu_display(GtkWidget *Aliste, gpointer Adata);
 extern void change_remplissage(GtkWidget *Acombo, gpointer Adata);
 extern gboolean on_select_files (GtkTreeSelection *Aselection, GtkTreeModel *Amodel,
                        GtkTreePath *Apath, gboolean Apath_currently_selected, gpointer Adata);
@@ -397,7 +423,8 @@ extern gboolean update_media_fields(GtkWidget *Awidget, gpointer Adata);
 extern void gtk_def_imageboot(GtkWidget *Abtn, gpointer Adata);
 extern gboolean quit_property(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
 extern gboolean on_deleteevent_gravure(GtkWidget *Awidget, GdkEvent *Aevent, gpointer Adata);
-
+extern void gtk_display_switchstatusbar(GtkWidget *Abtn, gpointer Adata);
+extern void gtk_display_updatesize(GtkWidget *Abtn, gpointer Adata);
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
