@@ -58,7 +58,7 @@ gboolean mkisofs_makeimage_callback(GIOChannel *Astd, GIOCondition Acond, gpoint
 {
   GIOStatus Lstatus;
   GHashTable *Lhash = (GHashTable *)Adata;
-  gboolean *Lcont = (gboolean *) g_hash_table_lookup(Lhash, "cont"); /* on traite encore des donnees ? */
+  gint *Lcont = (gint *) g_hash_table_lookup(Lhash, "cont"); /* on traite encore des donnees ? */
   GError **Lerreur = (GError **) g_hash_table_lookup(Lhash, "gerror"); /* pointeur erreur */
   gint *Ltodo = (gint *) g_hash_table_lookup(Lhash, "todo"); /* nombre de piste a traiter */
   gint *Ldone = (gint *) g_hash_table_lookup(Lhash, "done"); /* nombre de piste deja traite */
@@ -70,7 +70,7 @@ gboolean mkisofs_makeimage_callback(GIOChannel *Astd, GIOCondition Acond, gpoint
 
   /* fin du callback lorsque l'on recoi un signal comme quoi le pipe est ferme */
   if (Acond == G_IO_HUP || Acond == G_IO_ERR) {
-    *Lcont = FALSE;
+    *Lcont = 0;
     return FALSE;
   }
   Lstatus = g_io_channel_read_line(Astd, &Lbuffer, NULL, NULL, NULL);    
@@ -92,7 +92,7 @@ _DEB("on recoi => '%s'\n", Lbuffer);
     g_snprintf(Lsbuf2, sizeof(Lsbuf2)-1, "%.0f%%", Ltava*100);
     gtk_progress_bar_set_text(Lprogressbar, Lsbuf2);
   } else if ((strstr(Lbuffer, MKISOFS_ERROR)) && (!strstr(Lbuffer, MKISOFS_IGNORE))) {
-    *Lcont = FALSE;
+    *Lcont = 0;
 
     if (!strstr(Lbuffer, MKISOFS_NOSPACE)) {
       Ltxt = _UTF8(Lbuffer);
@@ -111,7 +111,7 @@ _DEB("on recoi => '%s'\n", Lbuffer);
     gtk_progress_bar_set_fraction(Lprogressbar, Ltava);
     g_snprintf(Lsbuf2, sizeof(Lsbuf2)-1, "%.0f%%", Ltava*100);
     gtk_progress_bar_set_text(Lprogressbar, Lsbuf2);
-    *Lcont = FALSE;
+    *Lcont = 0;
     *Lopstatus = TRUE;
   }
 
@@ -126,7 +126,8 @@ gboolean make_iso(GHashTable *Ahash, GError **Aerror)
   gchar *Lcommandline;
   GIOChannel *Lcomerr, *Lcom;
   guint Lcomerrevent, Lcomevent;
-  gboolean Lcont = TRUE;
+  gint *Lcont = (gint *)g_hash_table_lookup(Ahash, "cont");
+  gboolean *Labort = (gboolean *) g_hash_table_lookup(Ahash, "gabort");
   gchar **Ltmpdir = (gchar **)g_hash_table_lookup(Ahash, "tmpdir");
   gchar **Lextrapara = (gchar **)g_hash_table_lookup(Ahash, "extrapara");
   gint *Lpid = (gint *) g_hash_table_lookup(Ahash, "pid");
@@ -159,23 +160,20 @@ gboolean make_iso(GHashTable *Ahash, GError **Aerror)
     g_warning("ERROR EXECUTION !\n");
     return FALSE;
   }
-  g_hash_table_insert(Ahash, "cont", &Lcont);
 
   Lcom = g_io_channel_unix_new( g_out );
   g_io_channel_set_encoding (Lcom, NULL, NULL);
-//  g_io_channel_set_buffered(Lcom, FALSE);
   g_io_channel_set_flags( Lcom, G_IO_FLAG_NONBLOCK, NULL );
   Lcomevent = g_io_add_watch (Lcom, (G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_PRI),
                                       mkisofs_makeimage_callback, Ahash);
 
   Lcomerr = g_io_channel_unix_new( g_err );
   g_io_channel_set_encoding (Lcomerr, NULL, NULL);
-//  g_io_channel_set_buffered(Lcomerr, FALSE);
   g_io_channel_set_flags( Lcomerr, G_IO_FLAG_NONBLOCK, NULL );
   Lcomerrevent = g_io_add_watch (Lcomerr, (G_IO_IN | G_IO_HUP | G_IO_ERR | G_IO_PRI),
                                       mkisofs_makeimage_callback, Ahash); 
 _DEB("debut !!");
-  while (Lcont == TRUE) {
+  while (*Lcont > 0 && *Labort == FALSE) {
    gtk_main_iteration();
   }
 
@@ -192,9 +190,6 @@ _DEB("fin !!");
   g_spawn_close_pid(*Lpid);
   *Lpid = 0;
 
-  g_hash_table_remove(Ahash, "cont");
-  
-
   if (*Aerror) {
     return FALSE;
   }
